@@ -4,7 +4,7 @@ package SNMP::Insight::MIB::Bridge;
 
 use Moose::Role;
 
-our $VERSION = '0.001';    #TRIAL VERSION:
+our $VERSION = '0.002';    #TRIAL VERSION:
 
 use SNMP::Insight::Moose::MIB;
 
@@ -12,7 +12,7 @@ use namespace::autoclean;
 with 'SNMP::Insight::MIB';
 
 mib_oid "1.3.6.1.2.1.17";
-mib_name "Bridge-MIB";
+mib_name "BRIDGE-MIB";
 
 # .1 dot1dBase
 
@@ -32,7 +32,9 @@ has_table "dot1dBasePortTable" => (
     }
 );
 
-# .4 to1dTp
+has_scalar "dot1dStpProtocolSpecification" => ( oid => "2.1" );
+
+# .4 dot1dTp
 
 has_table "dot1dTpFdbEntry" => (
     oid     => "4.3",
@@ -63,7 +65,7 @@ SNMP::Insight::MIB::Bridge - Support for data in Bridge-MIB
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
